==> packages-18.7-LibreSSL-amd64.tar: usr/local/opnsense/mvc/app/models/OPNsense/Base/BaseModelMigration.php <==
<?php
/**
*    Copyright (C) 2016 Deciso B.V.
*
*    All rights reserved.
*
*    Redistribution and use in source and binary forms, with or without
*    modification, are permitted provided that the following conditions are met:
*
*    1. Redistributions of source code must retain the above copyright notice,
*       this list of conditions and the following disclaimer.
*
*    2. Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in the
*       documentation and/or other materials provided with the distribution.
*
*    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
*    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
*    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
*    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
*    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
*    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
*    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
*    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
*    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
*    POSSIBILITY OF SUCH DAMAGE.
*
*/

namespace OPNsense\Base;

use OPNsense\Core\Config;
use Phalcon\Logger\Adapter\Syslog;

/**
 * @package OPNsense\Base
 */
class BaseModelMigration
{
    /**
     * Walk through all nodes and check required defaults
     * @param $node
     */
    private function checkDefaults($node)
    {
        foreach ($node->__items as $key => $subnode) {
            if (count($subnode->__items) > 0) {
                $this->checkDefaults($subnode);
            } elseif ($subnode->isEmptyAndRequired()) {
                $subnode->applyDefault();
            }
        }
    }

    /**
     * default model migration
     * @param $model
     */
    public function run($model)
    {
        $this->checkDefaults($model);
    }

    /**
     * post migration action, run after config sync
     * @param $model
     */
    public function post($model)
    {
        return;
    }
}

==> packages-20.7-LibreSSL-amd64.tar: usr/local/opnsense/mvc/app/models/OPNsense/Base/BaseModelMigration.php <==
<?php

/**
*    Copyright (C) 2016 Deciso B.V.
*
*    All rights reserved.
*
*    Redistribution and use in source and binary forms, with or without
*    modification, are permitted provided that the following conditions are met:
*
*    1. Redistributions of source code must retain the above copyright notice,
*       this list of conditions and the following disclaimer.
*
*    2. Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in the
*       documentation and/or other materials provided with the distribution.
*
*    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
*    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
*    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
*    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
*    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
*    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
*    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
*    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
*    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
*    POSSIBILITY OF SUCH DAMAGE.
*
*/

namespace OPNsense\Base;

use OPNsense\Core\Config;
use Phalcon\Logger\Adapter\Syslog;

/**
 * @package OPNsense\Base
 */
class BaseModelMigration
{
    /**
     * Walk through all nodes and check required defaults
     * @param $node
     */
    private function checkDefaults($node)
    {
        foreach ($node->iterateItems() as $key => $subnode) {
            if (count(iterator_to_array($subnode->iterateItems())) > 0) {
                $this->checkDefaults($subnode);
            } elseif ($subnode->isEmptyAndRequired()) {
                $subnode->applyDefault();
            }
        }
    }

    /**
     * default model migration
     * @param $model
     */
    public function run($model)
    {
        $this->checkDefaults($model);
    }

    /**
     * post migration action, run after config sync
     * @param $model
     */
    public function post($model)
    {
        return;
    }
}
